@@ -62,7 +62,7 @@ class MetaDocument(type):
                     f"Required attribute {field} is missing."
                 )
 
-        return cls._client_.client[cls._database_][cls._collection_]
+        return cls._client_[cls._database_][cls._collection_]
 
 
 class Document(metaclass=MetaDocument):
